import { Exome } from "exome";
/**
 * For `loadState`` to know what stores to build instances from, we must make sure we register them.
 *
 * @example:
 * ```ts
 * registerLoadable({
 *   CounterStore,
 * })
 * ```
 */
export declare const registerLoadable: (config: Record<string, any>) => void;
/**
 * Loads saved store into existing store instance. It will rebuild all children stores too.
 *
 * @example:
 * ```ts
 * const counterStore = new CounterStore()
 * const savedStore = `{"$$exome_id":"CounterStore-LS5WUJPF17SF","count":200}`
 *
 * loadState(counterStore, savedStore)
 * ```
 */
export declare const loadState: (store: Exome, state: string) => any;
